@@ -7,6 +7,8 @@ use tokio_util::io::ReaderStream;
 
 use crate::address::ParsedAddress;
 use crate::bar::WrappedBar;
+use crate::consts::*;
+use crate::error::ValidateError;
 use crate::hash::HashChecker;
 use crate::io::get_output;
 use crate::slicer::Slicer;
@@ -29,12 +31,12 @@ impl FTPHandler {
         output: &str,
         bar: &mut WrappedBar,
         expected_sha256: &str,
-    ) -> bool {
+    ) -> Result<(), ValidateError> {
         let _output = match output {
             "." => Slicer::target_with_extension(input),
             _ => output,
         };
-        FTPHandler::_get(input, _output, bar).await;
+        FTPHandler::_get(input, _output, bar).await?;
         HashChecker::check(_output, expected_sha256, bar.silent)
     }
 
@@ -48,7 +50,7 @@ impl FTPHandler {
         let parsed_address = ParsedAddress::parse_address(input, bar.silent);
         let mut ftp_stream = FTPHandler::get_stream(transfered, &parsed_address)
             .await
-            .unwrap();
+            .expect("Cannot get FTP stream");
         let total_size = ftp_stream
             .size(&parsed_address.file)
             .await
@@ -56,7 +58,10 @@ impl FTPHandler {
             .unwrap() as u64;
 
         bar.set_length(total_size);
-        let reader = ftp_stream.get(&parsed_address.file).await.unwrap();
+        let reader = ftp_stream
+            .get(&parsed_address.file)
+            .await
+            .expect("Cannot download file via FTP");
         Ok(FTPGetProperties {
             out,
             transfered,
@@ -65,11 +70,15 @@ impl FTPHandler {
         })
     }
 
-    async fn _get(input: &str, output: &str, bar: &mut WrappedBar) {
+    async fn _get(input: &str, output: &str, bar: &mut WrappedBar) -> Result<(), ValidateError> {
         let mut properties = FTPHandler::setup(input, output, bar).await.unwrap();
         loop {
-            let mut buffer = vec![0; 26214400usize];
-            let byte_count = properties.reader.read(&mut buffer[..]).await.unwrap();
+            let mut buffer = vec![0; BUFFER_SIZE];
+            let byte_count = properties
+                .reader
+                .read(&mut buffer[..])
+                .await
+                .expect("Cannot read FTP stream");
 
             buffer.truncate(byte_count);
             if !buffer.is_empty() {
@@ -90,17 +99,24 @@ impl FTPHandler {
         }
 
         bar.finish_download(&input, &output);
+        Ok(())
     }
 
-    pub async fn put(input: &str, output: &str, mut bar: WrappedBar) -> bool {
-        let file = tokio::fs::File::open(&input).await.unwrap();
-        let total_size = file.metadata().await.unwrap().len();
+    pub async fn put(input: &str, output: &str, mut bar: WrappedBar) -> Result<(), ValidateError> {
+        let file = tokio::fs::File::open(&input)
+            .await
+            .expect("Cannot read input file");
+        let total_size = file
+            .metadata()
+            .await
+            .expect("Cannot determine input file length")
+            .len();
 
         let parsed_address = ParsedAddress::parse_address(output, bar.silent);
         let transfered = 0;
         let mut ftp_stream = FTPHandler::get_stream(transfered, &parsed_address)
             .await
-            .unwrap();
+            .expect("Cannot get stream");
         let mut reader_stream = ReaderStream::new(file);
 
         bar.set_length(total_size);
@@ -125,9 +141,9 @@ impl FTPHandler {
         ftp_stream
             .put(&parsed_address.file, &mut stream_reader)
             .await
-            .unwrap();
+            .expect("Cannot upload file via FTP");
 
-        true
+        Ok(())
     }
 
     async fn get_stream(
@@ -136,18 +152,27 @@ impl FTPHandler {
     ) -> Result<async_ftp::FtpStream, async_ftp::FtpError> {
         let mut ftp_stream = FtpStream::connect((*parsed_address).server.clone())
             .await
-            .unwrap();
+            .expect("Cannot connect to FTP server");
         let _ = ftp_stream
             .login(&parsed_address.username, &parsed_address.password)
             .await
-            .unwrap();
+            .expect("Cannot login to FTP server");
 
         for path in &parsed_address.path_segments {
-            ftp_stream.cwd(&path).await.unwrap();
+            ftp_stream
+                .cwd(&path)
+                .await
+                .expect("Path in FTP URL does not exist on remote");
         }
 
-        ftp_stream.transfer_type(FileType::Binary).await.unwrap();
-        ftp_stream.restart_from(transfered).await.unwrap();
+        ftp_stream
+            .transfer_type(FileType::Binary)
+            .await
+            .expect("Cannot set transfer type to binary");
+        ftp_stream
+            .restart_from(transfered)
+            .await
+            .expect("Cannot restart transfer from already transfered byte count");
         Ok(ftp_stream)
     }
 }
@@ -166,7 +191,7 @@ async fn get_ftp_works() {
     .await;
     std::fs::remove_file(out_file).unwrap();
 
-    assert!(result);
+    assert!(result.is_ok());
 }
 
 #[tokio::test]
@@ -183,21 +208,17 @@ async fn get_ftp_works_same_filename() {
     .await;
     std::fs::remove_file("README").unwrap();
 
-    assert!(result);
+    assert!(result.is_ok());
 }
 
 #[tokio::test]
 async fn get_ftp_resume_works() {
-    let expected_size = 1370827;
-    let out_file = "test/wpa_supplicant-2:2.9-8-x86_64.pkg.tar.zst";
+    let expected_size = 989941;
+    let out_file = "test/get_ftp_resume_works";
 
-    std::fs::copy(
-        "test/incomplete_wpa_supplicant-2XX2.9-8-x86_64.pkg.tar.zst",
-        out_file,
-    )
-    .unwrap();
-    FTPHandler::get(
-        "ftp://ftp.fau.de/archlinux/core/os/x86_64/wpa_supplicant-2:2.9-8-x86_64.pkg.tar.zst",
+    std::fs::copy("test/incomplete_debian_bullseye_ChageLog", out_file).unwrap();
+    let _ = FTPHandler::get(
+        "ftp://ftp.fau.de/debian/dists/bullseye/ChangeLog",
         out_file,
         &mut WrappedBar::new_empty(),
         "",
