@@ -6,8 +6,9 @@ use tokio_util::io::ReaderStream;
 use crate::address::ParsedAddress;
 use crate::bar::WrappedBar;
 use crate::consts::*;
+use crate::error::ValidateError;
 use crate::hash::HashChecker;
-use crate::io::get_output;
+use crate::io;
 use crate::slicer::Slicer;
 
 pub struct HTTPSHandler;
@@ -17,19 +18,25 @@ impl HTTPSHandler {
         output: &str,
         bar: &mut WrappedBar,
         expected_sha256: &str,
-    ) -> bool {
+    ) -> Result<(), ValidateError> {
         let _output = match output {
             "." => Slicer::target_with_extension(input),
             _ => output,
         };
-        HTTPSHandler::_get(input, _output, bar).await;
+        HTTPSHandler::_get(input, _output, bar).await?;
         HashChecker::check(_output, expected_sha256, bar.silent)
     }
 
-    pub async fn put(input: &str, output: &str, mut bar: WrappedBar) -> bool {
+    pub async fn put(input: &str, output: &str, mut bar: WrappedBar) -> Result<(), ValidateError> {
         let parsed_address = ParsedAddress::parse_address(output, bar.silent);
-        let file = tokio::fs::File::open(&input).await.unwrap();
-        let total_size = file.metadata().await.unwrap().len();
+        let file = tokio::fs::File::open(&input)
+            .await
+            .expect("Cannot open input file for HTTPS read");
+        let total_size = file
+            .metadata()
+            .await
+            .expect("Cannot determine input file size for HTTPS read")
+            .len();
         let input_ = input.to_string();
         let output_ = output.to_string();
         let mut reader_stream = ReaderStream::new(file);
@@ -64,12 +71,12 @@ impl HTTPSHandler {
             .send()
             .await
             .unwrap();
-        return true;
+        Ok(())
     }
 
-    async fn _get(input: &str, output: &str, bar: &mut WrappedBar) {
+    async fn _get(input: &str, output: &str, bar: &mut WrappedBar) -> Result<(), ValidateError> {
         let parsed_address = ParsedAddress::parse_address(input, bar.silent);
-        let (mut out, mut downloaded) = get_output(output, bar.silent);
+        let (mut out, mut downloaded) = io::get_output(output, bar.silent);
 
         let res = Client::new()
             .get(input)
@@ -99,6 +106,7 @@ impl HTTPSHandler {
         }
 
         bar.finish_download(&input, &output);
+        Ok(())
     }
 
     async fn get_already_uploaded(output: &str, silent: bool) -> u64 {
@@ -129,7 +137,7 @@ async fn get_https_works() {
 
     let result = HTTPSHandler::get("https://github.com/XAMPPRocky/tokei/releases/download/v12.0.4/tokei-x86_64-unknown-linux-gnu.tar.gz", out_file, &mut WrappedBar::new_empty(), expected_hash).await;
 
-    assert!(result);
+    assert!(result.is_ok());
     std::fs::remove_file(out_file).unwrap();
 }
 
@@ -140,7 +148,7 @@ async fn get_https_works_same_filename() {
 
     let result = HTTPSHandler::get("https://github.com/casey/just/releases/download/0.10.2/just-0.10.2-x86_64-unknown-linux-musl.tar.gz", out_file, &mut WrappedBar::new_empty(), expected_hash).await;
 
-    assert!(result);
+    assert!(result.is_ok());
     std::fs::remove_file("just-0.10.2-x86_64-unknown-linux-musl.tar.gz").unwrap();
 }
 
@@ -154,7 +162,7 @@ async fn get_resume_works() {
     )
     .unwrap();
 
-    HTTPSHandler::get("https://github.com/Byron/dua-cli/releases/download/v2.10.2/dua-v2.10.2-x86_64-unknown-linux-musl.tar.gz", out_file, &mut WrappedBar::new_empty_verbose(), "").await;
+    let _ = HTTPSHandler::get("https://github.com/Byron/dua-cli/releases/download/v2.10.2/dua-v2.10.2-x86_64-unknown-linux-musl.tar.gz", out_file, &mut WrappedBar::new_empty_verbose(), "").await;
 
     let actual_size = std::fs::metadata(out_file).unwrap().len();
     assert_eq!(actual_size, expected_size);
