@@ -2,9 +2,13 @@ pub mod address;
 pub mod bar;
 pub mod consts;
 pub mod driver;
+pub mod error;
 pub mod ftp;
 pub mod hash;
 pub mod https;
 pub mod io;
 pub mod netrc;
 pub mod slicer;
+pub mod ssh;
+pub mod ssh_auth;
+pub mod untildify;
